@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.12;
 
-our $VERSION = '0.5';
+our $VERSION = '0.6';
 
 use App::Cmd::Setup -app;
 
@@ -35,8 +35,8 @@ sub _build_linux {
 
   # TODO improve result name detection
   my $file = "$project-$version-linux.tgz";
-  unless (copy("bazel-bin/$target.tgz", $file)) {
-    say STDERR "Copy bazel-bin/$target.tgz to $file failed: $!";
+  unless (copy("bazel-bin/$target.tar.gz", $file)) {
+    say STDERR "Copy bazel-bin/$target.tar.gz to $file failed: $!";
     return undef;
   }
 
